@@ -22,6 +22,10 @@
 #define	roundup(x, y)	((((x)+((y)-1))/(y))*(y))  /* to any y */
 #endif
 
+#ifndef MAX
+#define MAX(X,Y) ((X) > (Y) ? (X) : (Y))
+#endif
+
 #ifndef MIN
 #define MIN(X,Y) ((X) < (Y) ? (X) : (Y))
 #endif
@@ -98,7 +102,9 @@ void buffer_put_char(Buffer *buffer, int value);
 uint32_t buffer_get_utf8(Buffer *buffer, Buffer *utf8, uint32_t len_hint);
 uint32_t buffer_get_latin1_as_utf8(Buffer *buffer, Buffer *utf8, uint32_t len_hint);
 uint32_t buffer_get_utf16_as_utf8(Buffer *buffer, Buffer *utf8, uint32_t len, uint8_t byteorder);
+#ifdef HAS_GUID
 void buffer_get_guid(Buffer *buffer, GUID *g);
+#endif
 int buffer_get_float32_le_ret(float *ret, Buffer *buffer);
 float buffer_get_float32_le(Buffer *buffer);
 float get_f32le(const void *vp);
@@ -106,6 +112,8 @@ int buffer_get_float32_ret(float *ret, Buffer *buffer);
 float buffer_get_float32(Buffer *buffer);
 float get_f32(const void *vp);
 double buffer_get_ieee_float(Buffer *buffer);
+void put_u16(void *vp, uint16_t v);
+void put_u32(void *vp, uint32_t v);
 uint32_t buffer_get_bits(Buffer *buffer, uint32_t bits);
 uint32_t buffer_get_syncsafe(Buffer *buffer, uint8_t bytes);
 
